@@ -3,8 +3,9 @@
 import json
 from pathlib import Path
 
+from pydantic.json_schema import models_json_schema
+
 from curies import Records
-from curies._pydantic_compat import PYDANTIC_V1
 
 HERE = Path(__file__).parent.resolve()
 PATH = HERE.joinpath("schema.json")
@@ -27,24 +28,11 @@ def main() -> None:
         "$id": URL,
     }
 
-    if PYDANTIC_V1:
-        import pydantic.schema
-
-        # see https://docs.pydantic.dev/latest/usage/json_schema/#general-notes-on-json-schema-generation
-
-        schema_dict = pydantic.schema.schema(
-            [Records],
-            title=TITLE,
-            description=DESCRIPTION,
-        )
-    else:
-        from pydantic.json_schema import models_json_schema
-
-        _, schema_dict = models_json_schema(
-            [(Records, "validation")],
-            title=TITLE,
-            description=DESCRIPTION,
-        )
+    _, schema_dict = models_json_schema(
+        [(Records, "validation")],
+        title=TITLE,
+        description=DESCRIPTION,
+    )
 
     rv.update(schema_dict)
     PATH.write_text(json.dumps(rv, indent=2) + "\n")
