@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """Trivial version test."""
 
 import json
@@ -19,6 +17,8 @@ from curies.api import (
     DuplicatePrefixes,
     DuplicateURIPrefixes,
     ExpansionError,
+    NamedReference,
+    NoCURIEDelimiterError,
     PrefixStandardizationError,
     Record,
     Records,
@@ -45,12 +45,80 @@ GO_URI_PREFIX = "http://purl.obolibrary.org/obo/GO_"
 class TestStruct(unittest.TestCase):
     """Test the data structures."""
 
+    def test_not_curie(self):
+        """Test a malformed CURIE."""
+        with self.assertRaises(NoCURIEDelimiterError) as e:
+            Reference.from_curie("not a curie")
+        self.assertIn("does not appear to be a CURIE", str(e.exception))
+
+    def test_default_prefix(self) -> None:
+        """Test a default (empty) prefix."""
+        ref = Reference.from_curie(":something")
+        self.assertEqual("", ref.prefix)
+        self.assertEqual("something", ref.identifier)
+
+    def test_default_identifier(self) -> None:
+        """Test a default (empty) identifier."""
+        ref = Reference.from_curie("p1:")
+        self.assertEqual("p1", ref.prefix)
+        self.assertEqual("", ref.identifier)
+
+    def test_multiple_delimiters(self) -> None:
+        """Test a default (empty) identifier."""
+        ref = Reference.from_curie("a1:b2:c3")
+        self.assertEqual("a1", ref.prefix)
+        self.assertEqual("b2:c3", ref.identifier)
+
     def test_records(self):
         """Test a list of records."""
         records = Records.parse_obj([{"prefix": "chebi", "uri_prefix": CHEBI_URI_PREFIX}])
         converter = Converter(records=records)
         self.assertEqual({"chebi"}, converter.get_prefixes())
 
+    def test_sort(self):
+        """Test sorting."""
+        start = [
+            Reference.from_curie("def:1234"),
+            Reference.from_curie("abc:1234"),
+            Reference.from_curie("abc:1235"),
+        ]
+        expected = [
+            Reference.from_curie("abc:1234"),
+            Reference.from_curie("abc:1235"),
+            Reference.from_curie("def:1234"),
+        ]
+        self.assertEqual(expected, sorted(start))
+
+    def test_set_membership(self):
+        """Test membership in sets."""
+        collection = {
+            Reference.from_curie("def:1234"),
+            Reference.from_curie("abc:1234"),
+            Reference.from_curie("abc:1235"),
+        }
+        self.assertIn(Reference.from_curie("def:1234"), collection)
+        self.assertNotIn(Reference.from_curie("xyz:1234"), collection)
+        self.assertNotIn(Reference.from_curie(":1234"), collection)
+        self.assertNotIn(Reference.from_curie("abc:"), collection)
+
+    def test_named_set_membership(self):
+        """Test membership in sets of named references."""
+        references = {
+            NamedReference.from_curie("a:1", "name1"),
+            NamedReference.from_curie("a:2", "name2"),
+        }
+        self.assertIn(Reference.from_curie("a:1"), references)
+        self.assertIn(NamedReference.from_curie("a:1", "name1"), references)
+        # the following is a weird case, but shows how this works
+        self.assertIn(NamedReference.from_curie("a:1", "name2"), references)
+
+        references_2 = {
+            Reference.from_curie("a:1"),
+            Reference.from_curie("a:2"),
+        }
+        self.assertIn(Reference.from_curie("a:1"), references_2)
+        self.assertIn(NamedReference.from_curie("a:1", "name1"), references_2)
+
 
 class TestAddRecord(unittest.TestCase):
     """Test adding records."""
@@ -733,7 +801,7 @@ class TestConverter(unittest.TestCase):
                 path = Path(directory).joinpath("test.tsv")
                 with path.open("w") as file:
                     for row in rows:
-                        print(*row, sep="\t", file=file)  # noqa:T201
+                        print(*row, sep="\t", file=file)
 
                 idx = 1 if header else 0
 
